Naming conventions
=======================================================================

Here we discuss the naming conventions used within the bxflow source code.

variables
    lowercase, underscores

constants
    uppercase, underscores

classes
    camel case

class methods
    lowercase, underscores

imports
    require fully qualified package name (impore <package> does nothing)

    exception: top-level packages __init__.py will have __version__ defined in them

python packages
    lowercase, underscores

repository
    lowercase, hyphens

